@@ -1,4 +1,3 @@
-import json
 from pathlib import Path
 from typing import (
     Any,
@@ -28,7 +27,7 @@ from datamodel_code_generator.imports import (
 from datamodel_code_generator.model import DataModel, DataModelFieldBase
 from datamodel_code_generator.model.enum import Enum
 
-from ..parser.base import Parser, get_singular_name
+from ..parser.base import Parser
 from ..types import DataType, Types
 
 
@@ -389,19 +388,40 @@ class JsonSchemaParser(Parser):
                         )
                     ]
                 elif isinstance(field.additionalProperties, JsonSchemaObject):
+                    unresolved_type: str
                     field_class_name = self.model_resolver.add(
                         [*path, field_name], field_name, class_name=True
                     ).name
 
                     # TODO: supports other type
                     if field.additionalProperties.is_array:
-                        additional_properties_type = self.parse_array(
-                            field_class_name,
-                            field.additionalProperties,
-                            [*path, field_name],
-                        ).name
+                        if (
+                            isinstance(
+                                field.additionalProperties.items, JsonSchemaObject
+                            )
+                            and field.additionalProperties.items.ref
+                        ):
+                            unresolved_type = self.model_resolver.add_ref(
+                                field.additionalProperties.items.ref
+                            ).name
+                            additional_properties_type = self.data_type(
+                                type=f"List[{unresolved_type}]",
+                                imports_=[IMPORT_LIST],
+                                ref=True,
+                                version_compatible=True,
+                            ).type
+                        else:
+                            additional_properties_type = (
+                                unresolved_type
+                            ) = self.parse_array(
+                                field_class_name,
+                                field.additionalProperties,
+                                [*path, field_name],
+                            ).name
                     else:
-                        additional_properties_type = self.parse_object(
+                        additional_properties_type = (
+                            unresolved_type
+                        ) = self.parse_object(
                             field_class_name,
                             field.additionalProperties,
                             [*path, field_name],
@@ -415,7 +435,7 @@ class JsonSchemaParser(Parser):
                         self.data_type(
                             type=f'Dict[str, {additional_properties_type}]',
                             imports_=[IMPORT_DICT],
-                            unresolved_types=[additional_properties_type],
+                            unresolved_types=[unresolved_type],
                         )
                     ]
                 else:
