@@ -7,7 +7,7 @@ import pytest
 import yaml
 
 from datamodel_code_generator import DataModelField
-from datamodel_code_generator.imports import Import
+from datamodel_code_generator.imports import IMPORT_OPTIONAL, Import
 from datamodel_code_generator.model.pydantic import BaseModel, CustomRootType
 from datamodel_code_generator.parser.base import dump_templates
 from datamodel_code_generator.parser.jsonschema import (
@@ -104,7 +104,7 @@ def test_json_schema_object_ref_url_yaml(mocker):
     assert (
         dump_templates(list(parser.results))
         == '''class User(BaseModel):
-    name: Optional[str] = None'''
+    name: Optional[str] = Field(None, example='ken')'''
     )
     parser.parse_ref(obj, [])
     mock_get.assert_called_once_with('https://example.org/schema.yaml',)
@@ -133,11 +133,11 @@ def test_json_schema_object_cached_ref_url_yaml(mocker):
     assert (
         dump_templates(list(parser.results))
         == '''class Pet(BaseModel):
-    name: Optional[str] = None
+    name: Optional[str] = Field(None, examples=['dog', 'cat'])
 
 
 class User(BaseModel):
-    name: Optional[str] = None'''
+    name: Optional[str] = Field(None, example='ken')'''
     )
     mock_get.assert_called_once_with('https://example.org/schema.yaml',)
 
@@ -163,7 +163,7 @@ def test_json_schema_ref_url_json(mocker):
 
 
 class User(BaseModel):
-    name: Optional[str] = None'''
+    name: Optional[str] = Field(None, example='ken')'''
     )
     mock_get.assert_called_once_with('https://example.org/schema.json',)
 
@@ -382,11 +382,10 @@ def test_get_data_type(schema_type, schema_format, result_type, from_, import_):
 def test_get_data_type_array(schema_types, result_types):
     parser = JsonSchemaParser(BaseModel, CustomRootType)
     assert parser.get_data_type(JsonSchemaObject(type=schema_types)) == [
-        DataType(type=r) for r in result_types
+        DataType(
+            type=r,
+            optional='null' in schema_types,
+            imports_=[IMPORT_OPTIONAL] if 'null' in schema_types else None,
+        )
+        for r in result_types
     ]
-
-
-def test_get_data_type_invalid_obj():
-    with pytest.raises(ValueError, match='invalid schema object'):
-        parser = JsonSchemaParser(BaseModel, CustomRootType)
-        assert parser.get_data_type(JsonSchemaObject())
